..
    Copyright (C) 2020 UCT Prague.

    oarepo-validate is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Authors
=======

OArepo Validate library for record validation

- UCT Prague <simeki@vscht.cz>
